@@ -109,6 +109,7 @@ has _sort_order => (
         joined_so      => 'join',
         clear_sort_order => 'clear',
         sort_order_is_empty =>  'is_empty',
+        filter_sort_order => 'grep',
     },
 );
 
@@ -122,6 +123,8 @@ sub sort_order {
         if shift;
     if (grep {not defined} $self->sort_orders) {
         return '';
+    } elsif ($self->sort_orders == 0) {
+        return $self->get_view(0) . ' asc';
     } else {
         return $self->joined_so(' ');
     } 
@@ -1030,6 +1033,25 @@ sub validate_consistency {
     return undef;
 }
 
+sub is_in_view {
+    my ($self, $path) = @_;
+    return if $self->view_is_empty;
+    return grep {$path eq $_} $self->views;
+}
+
+sub clean_out_irrelevant_sort_orders {
+    my $self = shift;
+    return if $self->view_is_empty;
+    return if (not $self->has_sort_order or $self->sort_order_is_empty);
+    my @relevant_sos = $self->filter_sort_order(sub {$self->is_in_view($_->path)});
+    if (@relevant_sos) {
+        $self->_set_sort_order(\@relevant_sos);
+    } else {
+        $self->clear_sort_order;
+    }
+    return;
+}
+
 sub validate_sort_order {
     my $self = shift;
     return if $self->view_is_empty;
